![logo](https://github.com/jbr-ai-labs/marlben/assets/22059171/cab386fb-3b49-4f02-b59a-49dd2de3cc9c)

![marlben-tests](../../actions/workflows/python-package-conda.yml/badge.svg)

Marlben is a multi-agent reinforcement learning benchmark based on the [NeuralMMO](https://github.com/NeuralMMO/environment) game engine

## Installation
https://github.com/jbr-ai-labs/marlben/wiki/Quick-Start#installation

## Usage

https://github.com/jbr-ai-labs/marlben/wiki/Quick-Start#launching-an-environment

## Wiki
https://github.com/jbr-ai-labs/marlben/wiki
